==> neper-1.8.0.tgz: neper-1.8.0/src/Utils/TessUtils/Import/TessImport4.c <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2004-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include "TessImport.h"

void
TIVerParGerm (struct TESS *pTess, int ver, FILE * file)
{
  int i;

  for (i = 0; i <= 3; i++)
    fscanf (file, "%d", &(*pTess).VerGerm[ver][i]);

  return;
}

void
TIVerParEdge (struct TESS *pTess, int ver, FILE * file)
{
  int i;

  for (i = 0; i <= 3; i++)
    fscanf (file, "%d", &(*pTess).VerEdge[ver][i]);

  return;
}

void
TIVerCoo (struct TESS *pTess, int ver, FILE * file)
{
  int i;

  for (i = 0; i <= 2; i++)
    fscanf (file, "%lf", &(*pTess).VerCoo[ver][i]);

  return;
}

void
TIEdgeVerNb (struct TESS *pTess, int edge, FILE * file)
{
  int i;

  for (i = 0; i <= 1; i++)
    fscanf (file, "%d", &(*pTess).EdgeVerNb[edge][i]);

  return;
}

void
TIFaceGerm (struct TESS *pTess, int face, FILE * file)
{
  int i;

  for (i = 0; i <= 1; i++)
    fscanf (file, "%d", &(*pTess).FaceGerm[face][i]);

  return;
}

void
TIFaceEq (struct TESS *pTess, int face, FILE * file)
{
  int i;

  for (i = 0; i <= 3; i++)
    fscanf (file, "%lf", &(*pTess).FaceEq[face][i]);

  return;
}

void
TIFaceVerNEdgeProp (struct TESS *pTess, int face, FILE * file)
{
  int i;
  int tmp;

  fscanf (file, "%d", &(*pTess).FaceVerQty[face]);

  (*pTess).FaceVerNb[face] =
    oneDDoubleDAlloc_int ((*pTess).FaceVerQty[face] + 1);
  (*pTess).FaceEdgeNb[face] =
    oneDDoubleDAlloc_int ((*pTess).FaceVerQty[face] + 1);
  (*pTess).FaceEdgeOri[face] =
    oneDDoubleDAlloc_int ((*pTess).FaceVerQty[face] + 1);

  for (i = 1; i <= (*pTess).FaceVerQty[face]; i++)
    fscanf (file, "%d", &(*pTess).FaceVerNb[face][i]);
  for (i = 1; i <= (*pTess).FaceVerQty[face]; i++)
  {
    fscanf (file, "%d", &tmp);
    (*pTess).FaceEdgeNb[face][i] = fabs (tmp);
    (*pTess).FaceEdgeOri[face][i] = fabs (tmp) / tmp;
  }

  return;
}

void
TICenterCoo (struct TESS *pTess, int poly, FILE * file)
{
  int i;

  for (i = 0; i <= 2; i++)
    fscanf (file, "%lf", &(*pTess).CenterCoo[poly][i]);

  return;
}


void
TIPolyVerProp (struct TESS *pTess, int poly, FILE * file)
{
  int i;

  fscanf (file, "%d", &(*pTess).PolyVerQty[poly]);

  (*pTess).PolyVerNb[poly] =
    oneDDoubleDAlloc_int ((*pTess).PolyVerQty[poly] + 1);

  for (i = 1; i <= (*pTess).PolyVerQty[poly]; i++)
    fscanf (file, "%d", &(*pTess).PolyVerNb[poly][i]);

  return;
}


void
TIPolyEdgeProp (struct TESS *pTess, int poly, FILE * file)
{
  int i;

  fscanf (file, "%d", &(*pTess).PolyEdgeQty[poly]);

  (*pTess).PolyEdgeNb[poly] =
    oneDDoubleDAlloc_int ((*pTess).PolyEdgeQty[poly] + 1);

  for (i = 1; i <= (*pTess).PolyEdgeQty[poly]; i++)
    fscanf (file, "%d", &(*pTess).PolyEdgeNb[poly][i]);

  return;
}


void
TIPolyFaceProp (struct TESS *pTess, int poly, FILE * file)
{
  int i;
  int tmp;

  fscanf (file, "%d", &(*pTess).PolyFaceQty[poly]);

  (*pTess).PolyFaceNb[poly] =
    oneDDoubleDAlloc_int ((*pTess).PolyFaceQty[poly] + 1);
  (*pTess).PolyFaceOri[poly] =
    oneDDoubleDAlloc_int ((*pTess).PolyFaceQty[poly] + 1);

  for (i = 1; i <= (*pTess).PolyFaceQty[poly]; i++)
  {
    fscanf (file, "%d", &tmp);
    (*pTess).PolyFaceNb[poly][i] = fabs (tmp);
    (*pTess).PolyFaceOri[poly][i] = fabs (tmp) / tmp;
  }

  return;
}

==> neper-1.8.1.tgz: neper-1.8.1/src/Utils/TessUtils/Import/TessImport4.c <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2003-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include "TessImport.h"

void
TIVerParGerm (struct TESS *pTess, int ver, FILE * file)
{
  int i;

  for (i = 0; i <= 3; i++)
    fscanf (file, "%d", &(*pTess).VerGerm[ver][i]);

  return;
}

void
TIVerParEdge (struct TESS *pTess, int ver, FILE * file)
{
  int i;

  for (i = 0; i <= 3; i++)
    fscanf (file, "%d", &(*pTess).VerEdge[ver][i]);

  return;
}

void
TIVerCoo (struct TESS *pTess, int ver, FILE * file)
{
  int i;

  for (i = 0; i <= 2; i++)
    fscanf (file, "%lf", &(*pTess).VerCoo[ver][i]);

  return;
}

void
TIEdgeVerNb (struct TESS *pTess, int edge, FILE * file)
{
  int i;

  for (i = 0; i <= 1; i++)
    fscanf (file, "%d", &(*pTess).EdgeVerNb[edge][i]);

  return;
}

void
TIFaceGerm (struct TESS *pTess, int face, FILE * file)
{
  int i;

  for (i = 0; i <= 1; i++)
    fscanf (file, "%d", &(*pTess).FaceGerm[face][i]);

  return;
}

void
TIFaceEq (struct TESS *pTess, int face, FILE * file)
{
  int i;

  for (i = 0; i <= 3; i++)
    fscanf (file, "%lf", &(*pTess).FaceEq[face][i]);

  return;
}

void
TIFaceVerNEdgeProp (struct TESS *pTess, int face, FILE * file)
{
  int i;
  int tmp;

  fscanf (file, "%d", &(*pTess).FaceVerQty[face]);

  (*pTess).FaceVerNb[face] =
    ut_alloc_1d_int ((*pTess).FaceVerQty[face] + 1);
  (*pTess).FaceEdgeNb[face] =
    ut_alloc_1d_int ((*pTess).FaceVerQty[face] + 1);
  (*pTess).FaceEdgeOri[face] =
    ut_alloc_1d_int ((*pTess).FaceVerQty[face] + 1);

  for (i = 1; i <= (*pTess).FaceVerQty[face]; i++)
    fscanf (file, "%d", &(*pTess).FaceVerNb[face][i]);
  for (i = 1; i <= (*pTess).FaceVerQty[face]; i++)
  {
    fscanf (file, "%d", &tmp);
    (*pTess).FaceEdgeNb[face][i] = fabs (tmp);
    (*pTess).FaceEdgeOri[face][i] = fabs (tmp) / tmp;
  }

  return;
}

void
TICenterCoo (struct TESS *pTess, int poly, FILE * file)
{
  int i;

  for (i = 0; i <= 2; i++)
    fscanf (file, "%lf", &(*pTess).CenterCoo[poly][i]);

  return;
}


void
TIPolyVerProp (struct TESS *pTess, int poly, FILE * file)
{
  int i;

  fscanf (file, "%d", &(*pTess).PolyVerQty[poly]);

  (*pTess).PolyVerNb[poly] =
    ut_alloc_1d_int ((*pTess).PolyVerQty[poly] + 1);

  for (i = 1; i <= (*pTess).PolyVerQty[poly]; i++)
    fscanf (file, "%d", &(*pTess).PolyVerNb[poly][i]);

  return;
}


void
TIPolyEdgeProp (struct TESS *pTess, int poly, FILE * file)
{
  int i;

  fscanf (file, "%d", &(*pTess).PolyEdgeQty[poly]);

  (*pTess).PolyEdgeNb[poly] =
    ut_alloc_1d_int ((*pTess).PolyEdgeQty[poly] + 1);

  for (i = 1; i <= (*pTess).PolyEdgeQty[poly]; i++)
    fscanf (file, "%d", &(*pTess).PolyEdgeNb[poly][i]);

  return;
}


void
TIPolyFaceProp (struct TESS *pTess, int poly, FILE * file)
{
  int i;
  int tmp;

  fscanf (file, "%d", &(*pTess).PolyFaceQty[poly]);

  (*pTess).PolyFaceNb[poly] =
    ut_alloc_1d_int ((*pTess).PolyFaceQty[poly] + 1);
  (*pTess).PolyFaceOri[poly] =
    ut_alloc_1d_int ((*pTess).PolyFaceQty[poly] + 1);

  for (i = 1; i <= (*pTess).PolyFaceQty[poly]; i++)
  {
    fscanf (file, "%d", &tmp);
    (*pTess).PolyFaceNb[poly][i] = fabs (tmp);
    (*pTess).PolyFaceOri[poly][i] = fabs (tmp) / tmp;
  }

  return;
}
